# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='FacebookFan',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_facebookfan', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('url', models.URLField()),
                ('limit', models.IntegerField(default=100)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='FacebookPhoto',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_facebookphoto', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('url', models.URLField()),
                ('limit', models.IntegerField(default=100)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
